#ifndef __NEC_EMMA2_H
#define __NEC_EMMA2_H

#include <asm/addrspace.h>
#include <asm/vr41xx/vr41xx.h>

/*
 * Board specific address mapping
 */
#define VR41XX_PCI_MEM2_BASE		0x0
#define VR41XX_PCI_MEM2_SIZE		0x0
#define VR41XX_PCI_MEM2_MASK		0x0

#define VR41XX_PCI_MEM1_BASE		0x13000000
#define VR41XX_PCI_MEM1_SIZE		0x01000000
#define VR41XX_PCI_MEM1_MASK		0x7f000000

#define VR41XX_PCI_IO_BASE		0x15000000
#define VR41XX_PCI_IO_SIZE		0x08000000
#define VR41XX_PCI_IO_MASK		0x78000000

#define VR41XX_PCI_IO_START		0x00000000
#define VR41XX_PCI_IO_END		0x00ffffff

#define VR41XX_PCI_MEM_START		0x13000000
#define VR41XX_PCI_MEM_END		0x13ffffff

#define IO_PORT_BASE			KSEG1ADDR(VR41XX_PCI_IO_BASE)
#define IO_PORT_RESOURCE_START		0
#define IO_PORT_RESOURCE_END		VR41XX_PCI_IO_SIZE
#define IO_MEM1_RESOURCE_START		VR41XX_PCI_MEM1_BASE
#define IO_MEM1_RESOURCE_END		(VR41XX_PCI_MEM1_BASE + VR41XX_PCI_MEM1_SIZE)
#define IO_MEM2_RESOURCE_START		VR41XX_PCI_MEM2_BASE
#define IO_MEM2_RESOURCE_END		(VR41XX_PCI_MEM2_BASE + VR41XX_PCI_MEM2_SIZE)
#define EMMA2_BROI_FN_FSM  0xb0000400;

typedef struct
{
	uint32_t port_data_0;
	uint32_t port_data_1;
	uint32_t port_direction_0;
	uint32_t port_direction_1;
	uint32_t int_status_0;
	uint32_t int_status_1;
	uint32_t int_mode_0;
	uint32_t int_mode_1;
	uint32_t int_condition_a0;
	uint32_t int_condition_a1;
	uint32_t int_condition_b0;
	uint32_t int_condition_b1;
} zpio_regs;

#define zpio_regs_base ((volatile zpio_regs *)0xb2010c00)

typedef struct
{
	uint32_t rst;             uint32_t pad0[3];
	uint32_t pci_int;
	uint32_t inten;
	uint32_t intsta;          uint32_t pad1[1];
	uint32_t intex;
	uint32_t intexen;         uint32_t pad2[2];
	uint32_t arben;           uint32_t pad3[3];
	uint32_t pdar_intreg;
	uint32_t pdar_brg;
	uint32_t pdar_pciw0;
	uint32_t pdar_pciw1;
	uint32_t dma_eadr;
	uint32_t cbi_eadr;        uint32_t pad4[2];
	uint32_t arbctrl;         uint32_t pad5[3];
	uint32_t tendian;         uint32_t pad6[3];
	uint32_t dmactrl;
	uint32_t stadr;
	uint32_t ctadr;
	uint32_t etadr;
	uint32_t dmasta;          uint32_t pad7[3];
	uint32_t brgctrl;
} pci0_regs;

typedef struct
{
	                                uint32_t pad0[46];
	uint32_t err;             uint32_t pad1[9];
	uint32_t ctrl_l;
	uint32_t ctrl_h;
	uint32_t arb_l;
	uint32_t arb_h;
	uint32_t init0;           uint32_t pad2[1];
	uint32_t init1;           uint32_t pad3[65];
	uint32_t vid_did;
	uint32_t cmd_sts;
	uint32_t revid_class;
	uint32_t clsiz_mltim_htype;
	uint32_t barc;            uint32_t pad4[6];
	uint32_t ssvid_ssid;      uint32_t pad5[3];
	uint32_t intlin_intpin;
	uint32_t bar0;            uint32_t pad6[27];
	uint32_t swp;
} pci1_regs;

typedef struct
{
    uint32_t bhif_version;                char p0[12];
    uint32_t bhif_strap_1;
    uint32_t bhif_strap_2;                char p1[8];
    uint32_t bhif_strap_write_1;
    uint32_t bhif_strap_write_2;          char p2[8];
    uint32_t bhif_int_st_1;
    uint32_t bhif_int_st_2;               char p3[8];
    uint32_t bhif_int_en_1;
    uint32_t bhif_int_en_2;               char p4[8];
    uint32_t bhif_nmi_st;                 char p5[12];
    uint32_t bhif_nmi_en;                 char p6[12];
    uint32_t BHIF_BUS_PRIOR;              char p7[12];
    uint32_t BHIF_BERR_CLR;
    uint32_t BHIF_BERR_RLS;               char p8[8];
    uint32_t BHIF_BERR_CAUSE;             char p9[12];
    uint32_t BHIF_BERR_ADR;               char p10[12];
    uint32_t BHIF_BERR_RW;
    uint32_t BHIF_BERR_TARGET;            char p11[8];
    uint32_t BHIF_BERR_CPUMSK;            char p12[60];
    uint32_t BHIF_CLK_SEL_1;
    uint32_t BHIF_CLK_SEL_2;
    uint32_t BHIF_CLK_SEL_3;              char p13[4];
    uint32_t BHIF_CLK_MSK;                char p14[12];
    uint32_t BHIF_CLK_MCLKDIV;            char p15[12];
    uint32_t BHIF_CLK_MCLKRST;
} emma_bhif_regs;

#define emma_bhif (*((volatile emma_bhif_regs *)0xb0000000))

typedef struct
{
	uint32_t broi_fn_fsm;				char p0[12];
	uint32_t broi_oat_fat;				char p1[12];
	uint32_t broi_werr_wm;
} emma_broi_regs;


#define emma_broi (*((volatile emma_broi_regs *)0xb0000400))

#endif

